# PyTouchBar
A NSTouchBar Wrapper for Python. It only works (for the moment) with Tkinter and PyGame.<br>
It mainly depends on PyObjc to wrap NSTouchBar and related classes.<br>
It also includes a wrapper to the haptic trackpad, allowing your Python program to trigger trackpad vibrations.<br>
Note: It will (of course) only works on MacBook Pro with TouchBars, or on a TouchBar Simulator (<a href="https://github.com/sindresorhus/touch-bar-simulator">you have a good one here</a>.)

## What's new
#### 0.2.0:

* Add user-customization of the TouchBar
* Best error managment
* New Stepper item (macOS 10.15 +)
* Add escape key modification
* Improved file structure of the module

## Installation

To install PyTouchBar, just copy-paste the following command into a terminal:

    pip install PyTouchBar

## Example

Here is a simple example displaying a window with a label, and displaying a button in the touchbar.

```python
from tkinter import *
import PyTouchBar

root = Tk()
PyTouchBar.prepare_tk_windows(root) # Tell PyTouchBar that the "root" window will have a TouchBar

# Build Tkinter interface
lbl = Label(root, text="Hello World")
lbl.pack()

# Build TouchBar
def action(button):
    print ("Button Pressed !")

btn = PyTouchBar.items.Button(title="Button", action=action)
PyTouchBar.set_touchbar([btn])


root.mainloop()
```

## How to Use
All documentation is included in the wiki


  * <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Integrate-into-your-project">Integrate into your project</a>
  * <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar">Add items in TouchBar</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#Spaces">Spaces</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#Label">Labels</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#Button">Buttons</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#ColorPicker">Color Picker</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#Slider">Slider</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#Stepper">Stepper</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#SegmentedControls">Segmented Controls</a>
    -  <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Populate-TouchBar#Popover">Popover</a>
  * <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Constants">Constants</a>
  * <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Set-Escape-Key">Change esc key</a>
  * <a href="https://github.com/Maxmad68/PyTouchBar/wiki/User-customization">User Customization</a>
  * <a href="https://github.com/Maxmad68/PyTouchBar/wiki/Haptic-Feedback">Haptic Feedback</a>

